<?php
namespace Neunzehn84\ContentReplacer\Hooks;
/*
* This file is part of the TYPO3 CMS project.
*
* It is free software; you can redistribute it and/or modify it under
* the terms of the GNU General Public License, either version 2
* of the License, or any later version.
*
* For the full copyright and license information, please read the
* LICENSE.txt file that was distributed with this source code.
*
* The TYPO3 project - inspiring people to share!
*/

use TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController;

/**
 * Class ReplaceContent
 *
 * Replace a given set of regular expressions in the generated page (cached/uncached)
 *
 * @package Neunzehn84\ContentReplacer\Hooks
 * @author Daniel Schmidt <schmidt@neunzehn84.de>
 */
class ReplaceContent
{

    /**
     * Search for a given string by regular expression and replace it. The complete generated markup will be analyzed.
     *
     * You need to configure the search and replace patters by TypoScript. Therefore it is possible to replace content
     * only on specific pages depending on the TypoScript-Settings you choose. Attention: You need to use valid regular
     * expressions in preg_replace syntax, which means you have to escape your input strings. The number of replacement
     * patterns is not limited, but be aware of possible performance issues.
     *
     * Usage hint:
     * <code>
     * config.tx_n84_contentreplacer {
     *   search {
     *     1 = /something/
     *     2 = /else/
     *   }
     *   replace {
     *     1 = foo
     *     2 = bar
     *   }
     * }
     * </code>
     *
     * @param $parameters
     * @param TypoScriptFrontendController $parentObject
     */
    public function replaceContent(&$parameters, TypoScriptFrontendController $parentObject)
    {
        $config = $this->readConfiguration($parentObject);

        if (TYPO3_MODE === 'FE' && $config) {

            $parameters['pObj']->content = preg_replace(
                $config['search.'],
                $config['replace.'],
                $parameters['pObj']->content
            );

        }
    }

    /**
     * Analyze given TypoScript configuration and return if valid. Otherwise return null.
     *
     * @param TypoScriptFrontendController $parentObject
     * @return mixed
     */
    protected function readConfiguration(TypoScriptFrontendController $parentObject)
    {

        $config = $parentObject->config['config']['tx_n84_contentreplacer.'];

        if (!is_array($config['search.']) || !is_array($config['search.'])) {
            return null;
        }

        return $config;

    }

}
